==> react-relay-8.0.0.tgz: package/lib/hooks.js <==
/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 * @format
 */
'use strict';

var EntryPointContainer = require('./relay-experimental/EntryPointContainer.react');

var LazyLoadEntryPointContainer = require('./relay-experimental/LazyLoadEntryPointContainer.react');

var MatchContainer = require('./relay-experimental/MatchContainer');

var ProfilerContext = require('./relay-experimental/ProfilerContext');

var RelayEnvironmentProvider = require('./relay-experimental/RelayEnvironmentProvider');

var fetchQuery = require('./relay-experimental/fetchQuery');

var preloadQuery = require('./relay-experimental/preloadQuery');

var prepareEntryPoint = require('./relay-experimental/prepareEntryPoint');

var useBlockingPaginationFragment = require('./relay-experimental/useBlockingPaginationFragment');

var useFragment = require('./relay-experimental/useFragment');

var useLazyLoadQuery = require('./relay-experimental/useLazyLoadQuery');

var useLegacyPaginationFragment = require('./relay-experimental/useLegacyPaginationFragment');

var usePreloadedQuery = require('./relay-experimental/usePreloadedQuery');

var useRefetchableFragment = require('./relay-experimental/useRefetchableFragment');

var useRelayEnvironment = require('./relay-experimental/useRelayEnvironment');

var _require = require('relay-runtime'),
    graphql = _require.graphql;

/**
 * The public interface for Relay Hooks
 */
module.exports = {
  EntryPointContainer: EntryPointContainer,
  LazyLoadEntryPointContainer: LazyLoadEntryPointContainer,
  MatchContainer: MatchContainer,
  ProfilerContext: ProfilerContext,
  RelayEnvironmentProvider: RelayEnvironmentProvider,
  fetchQuery: fetchQuery,
  preloadQuery: preloadQuery,
  prepareEntryPoint: prepareEntryPoint,
  graphql: graphql,
  useBlockingPaginationFragment: useBlockingPaginationFragment,
  useFragment: useFragment,
  useLazyLoadQuery: useLazyLoadQuery,
  usePaginationFragment: useLegacyPaginationFragment,
  usePreloadedQuery: usePreloadedQuery,
  useRefetchableFragment: useRefetchableFragment,
  useRelayEnvironment: useRelayEnvironment
};

==> react-relay-10.0.0.tgz: package/lib/hooks.js <==
/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 * @format
 */
'use strict';

var EntryPointContainer = require('./relay-experimental/EntryPointContainer.react');

var MatchContainer = require('./relay-experimental/MatchContainer');

var ProfilerContext = require('./relay-experimental/ProfilerContext');

var RelayEnvironmentProvider = require('./relay-experimental/RelayEnvironmentProvider');

var fetchQuery = require('./relay-experimental/fetchQuery');

var loadQuery = require('./relay-experimental/loadQuery');

var loadEntryPoint = require('./relay-experimental/loadEntryPoint');

var useBlockingPaginationFragment = require('./relay-experimental/useBlockingPaginationFragment');

var useEntryPointLoader = require('./relay-experimental/useEntryPointLoader');

var useFragment = require('./relay-experimental/useFragment');

var useLazyLoadQuery = require('./relay-experimental/useLazyLoadQuery');

var useMutation = require('./relay-experimental/useMutation');

var usePaginationFragment = require('./relay-experimental/usePaginationFragment');

var usePreloadedQuery = require('./relay-experimental/usePreloadedQuery');

var useQueryLoader = require('./relay-experimental/useQueryLoader');

var useRefetchableFragment = require('./relay-experimental/useRefetchableFragment');

var useRelayEnvironment = require('./relay-experimental/useRelayEnvironment');

var useSubscribeToInvalidationState = require('./relay-experimental/useSubscribeToInvalidationState');

var useSubscription = require('./relay-experimental/useSubscription');

var _require = require('relay-runtime'),
    graphql = _require.graphql;

/**
 * The public interface for Relay Hooks
 */
module.exports = {
  EntryPointContainer: EntryPointContainer,
  MatchContainer: MatchContainer,
  ProfilerContext: ProfilerContext,
  RelayEnvironmentProvider: RelayEnvironmentProvider,
  fetchQuery: fetchQuery,
  loadEntryPoint: loadEntryPoint,
  loadQuery: loadQuery,
  graphql: graphql,
  useBlockingPaginationFragment: useBlockingPaginationFragment,
  useEntryPointLoader: useEntryPointLoader,
  useFragment: useFragment,
  useLazyLoadQuery: useLazyLoadQuery,
  useMutation: useMutation,
  usePaginationFragment: usePaginationFragment,
  usePreloadedQuery: usePreloadedQuery,
  useQueryLoader: useQueryLoader,
  useRefetchableFragment: useRefetchableFragment,
  useRelayEnvironment: useRelayEnvironment,
  useSubscribeToInvalidationState: useSubscribeToInvalidationState,
  useSubscription: useSubscription
};
